@@ -19,14 +19,15 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
+
 #ifndef KONQUEST_SCOREDLG_H
 #define KONQUEST_SCOREDLG_H
 
-
 #include <QTableWidget>
 #include <KDialog>
 
 #include "../players/player.h"
+#include "../view/standingswidget.h"
 
 
 class ScoreDlg : public KDialog
@@ -38,10 +39,7 @@ public:
     ~ScoreDlg();
 
 private:
-    void init();
-
-    QList<Player *>  m_players;
-    QTableWidget     *m_scoreTable;
+    StandingsWidget *m_standingsWidget;
 
 };
 
